# Copyright 2010-2011 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

__metaclass__ = type

__all__ = [
    "IDeviceCategory",
    "IDeviceCategorySet",
    "IHasDeviceCategory",
    ]

from zope.interface import (
    Attribute,
    Interface,
    )
from zope.schema import TextLine

from lazr.restful.declarations import exported


class IDeviceCategory(Interface):

    name = Attribute("Device category name")


class IHasDeviceCategory(Interface):
    """An entity which has a device category."""

    category = Attribute("Device category")

    category_name = exported(
        TextLine(
            title=u"Device category name",
            required=True,
            readonly=True))


class IDeviceCategorySet(Interface):

    def get(id):
        """Return the device category with the given id.

        If there's no device category with the given id, return None.

        :param id: The primary id associated with a device category.
        """

    def getByName(name):
        """Return the device category with the given name.

        If there's no device category with the given name, return None.

        :param name: The unique name associated with a device category.
        """
