# Copyright 2010-2011 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

__metaclass__ = type

__all__ = [
    "IProcessor",
    "IProcessorSet",
    ]

from zope.interface import Interface
from zope.schema import (
    Int,
    Text,
    TextLine,
    )

from lazr.restful.declarations import exported

from lpresults.hardware.interfaces.processorplatform import (
    IHasProcessorPlatform,
    )


class IProcessor(IHasProcessorPlatform):

    make = exported(
        TextLine(
            title=u"Make",
            required=True,
            readonly=True,
            description=u"The make for this processor."))

    model = exported(
        TextLine(
            title=u"Model",
            required=True,
            readonly=True,
            description=u"The model for this processor."))

    model_number = exported(
        TextLine(
            title=u"Model Number",
            required=True,
            readonly=True,
            description=u"Model number for this processor."))

    model_version = exported(
        TextLine(
            title=u"Model Version",
            required=True,
            readonly=True,
            description=u"Model version for this processor."))

    model_revision = exported(
        TextLine(
            title=u"Model Revision",
            required=True,
            readonly=True,
            description=u"Model revision for this processor."))

    cache = exported(
        Int(
            title=u"Cache",
            required=True,
            readonly=True,
            description=u"The amount of cache for this processor."))

    other = exported(
        Text(
            title=u"Other",
            description=u"Other information for this processor."))


class IProcessorSet(Interface):

    def get(id):
        """Return the processor with the given id.

        If there's no processor with the given id, return None.

        :param id: The primary id associated with a processor.
        """

    def getByName(
        platform_name, make, model, model_number, model_version,
        model_revision, cache, other):
        """Return the processor with the given names.

        If there's no processor with the given name, create one

        :param platform_name: The name of the platform.
        :param make: The make of the processor.
        :param model: The make of the processor.
        :param model_number: The model number.
        :param model_version: The model version.
        :param model_revision: The model revision.
        :param cache: The amount of cache in bytes.
        :param other: Other information like flags.
        """
