# Copyright 2010-2011 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

__metaclass__ = type

__all__ = [
    "IHasProcessorStates",
    "IProcessorState",
    "IProcessorStateSet",
    "IProcessorStateTarget",
    "ProcessorStateSearchParams",
    ]

from zope.interface import Interface
from zope.schema import (
    Datetime,
    Int,
    )

from lazr.restful.declarations import (
    export_as_webservice_entry,
    export_factory_operation,
    export_read_operation,
    exported,
    operation_parameters,
    operation_returns_collection_of,
    )
from lazr.restful.frameworks.django import IDjangoLocation

from lpresults.registry.interfaces.search import (
    ISearchSet,
    SearchParams,
    )

from lpresults.hardware.interfaces.processor import IProcessor


class IProcessorState(IDjangoLocation, IProcessor):

    export_as_webservice_entry()

    bogomips = exported(
        Int(
            title=u"Bogomips",
            required=True,
            readonly=True,
            description=u"The number of bogomips for this processor state."))

    speed = exported(
        Int(
            title=u"Speed",
            required=True,
            readonly=True,
            description=u"The speed for this processor state."))

    count = exported(
        Int(
            title=u"Bogomips",
            required=True,
            readonly=True,
            description=u"The number of processor for this state."))

    date_created = exported(
        Datetime(
            title=u"Date created",
            required=True,
            readonly=True,
            description=u"Date on which this processor state was created."))


class IProcessorStateSet(ISearchSet):

    pass


class IHasProcessorStates(Interface):

    @operation_parameters(
        date_created=Datetime(
            title=u"Search processors created on the given date",
            required=False),
        created_before=Datetime(
            title=u"Search processors created before or on the given date",
            required=False),
        created_after=Datetime(
            title=u"Search processors created after the given date",
            required=False),
        )
    @operation_returns_collection_of(IProcessorState)
    @export_read_operation()
    def getProcessorStates(
        date_created=None, created_before=None, created_after=None):
        """Get the processor states for this target."""


class IProcessorStateTarget(IHasProcessorStates):

    @export_factory_operation(
        IProcessorState, [
            "platform_name", "make", "model", "model_number",
            "model_version", "model_revision", "cache", "other",
            "bogomips", "speed", "count"])
    def setProcessorState(
        platform_name, make, model, model_number, model_version,
        model_revision, cache, other, bogomips, speed, count):
        """Set the processor state for this target."""


class ProcessorStateSearchParams(SearchParams):
    """Encapsulates search parameters for IProcessorStateSet.search()"""

    def __init__(
        self, date_created=None, created_before=None, created_after=None,
        **kwargs):
        super(ProcessorStateSearchParams, self).__init__(**kwargs)
        self.date_created = date_created
        self.created_before = created_before
        self.created_after = created_after
