# Copyright 2010-2011 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

__metaclass__ = type

__all__ = [
    "DeviceProduct",
    "DeviceProductTargetMixin",
    ]

from storm.locals import (
    Int,
    RawStr,
    Unicode,
    )

from zope.interface import implements

from lpresults.database.textgrams import get_text_grams_as_text
from lpresults.database.textsearch import (
    TSVectorPart,
    TSVectorValidator,
    )

from lpresults.hardware.interfaces.deviceproduct import (
    IDeviceProduct,
    IDeviceProductTarget,
    )
from lpresults.hardware.models.store import get_hardware_store


DEVICE_PRODUCT_VALIDATOR = TSVectorValidator(
    "text_search_vector",
    TSVectorPart(
        u"name", weight=u"A", transform=(get_text_grams_as_text,)))


class DeviceProduct:
    """A device product on a specific bus.

    A product can be given an optional identifier which must be less
    than or equal 0xFFFF otherwise the identifier will be automatically
    generated with a greater value. This makes it possible to mix products
    with known and unknown identifiers on the same bus.
    """
    __storm_table__ = "deviceproduct"
    __storm_primary__ = ("bus_id", "product_id", "vendor_id",)

    implements(IDeviceProduct)

    name = Unicode(allow_none=False, validator=DEVICE_PRODUCT_VALIDATOR)
    bus_id = Int(name="bus", allow_none=False)
    product_id = Int(name="product", allow_none=False)
    vendor_id = Int(name="vendor")

    text_search_vector = RawStr()


class DeviceProductTargetMixin:

    implements(IDeviceProductTarget)

    def getBusId(self):
        """See `IDeviceProductTarget`."""
        raise NotImplementedError()

    def setProduct(self, name, product_id, vendor_id):
        """See `IDeviceProductTarget`."""
        bus_id = self.getBusId()
        return get_hardware_store().execute(
            "SELECT set_device_product(?, ?, ?, ?)",
            (name, bus_id, product_id, vendor_id,),
            noresult=True)

    def setSubproduct(
        self, name, product_id, vendor_id, subproduct_id, subvendor_id):
        """See `IDeviceProductTarget`."""
        return get_hardware_store().execute(
            "SELECT set_device_subproduct(?, ?, ?, ?, ?)",
            (name, product_id, vendor_id, subproduct_id, subvendor_id,),
            noresult=True)
