# Copyright 2010-2011 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

__metaclass__ = type

__all__ = [
    "Processor",
    "processor_set",
    ]

from storm.locals import (
    AutoReload,
    Int,
    Reference,
    Unicode,
    )

from zope.interface import implements

from lpresults.hardware.interfaces.processor import (
    IProcessor,
    IProcessorSet,
    )
from lpresults.hardware.models.processorplatform import (
    ProcessorPlatform,
    HasProcessorPlatformMixin,
    )
from lpresults.hardware.models.store import get_hardware_store


class Processor(HasProcessorPlatformMixin):

    __storm_table__ = "processor"

    implements(IProcessor)

    id = Int(primary=True, allow_none=False, default=AutoReload)
    platform_id = Int(name="platform", allow_none=False)
    make = Unicode(allow_none=False)
    model = Unicode(allow_none=False)
    model_number = Unicode(allow_none=False)
    model_version = Unicode(allow_none=False)
    model_revision = Unicode(allow_none=False)
    cache = Int(allow_none=False)
    other = Unicode(allow_none=False)

    platform = Reference(platform_id, ProcessorPlatform.id)

    def __init__(self, platform, make, model, model_number,
            model_version, model_revision, cache, other):
        self.platform = platform
        self.make = make
        self.model = model
        self.model_number = model_number
        self.model_version = model_version
        self.model_revision = model_revision
        self.cache = cache
        self.other = other


class ProcessorSet:

    implements(IProcessorSet)

    def get(self, id):
        """See `IProcessorSet`."""
        return get_hardware_store().get(Processor, id)

    def getByName(
        self, platform_name, make, model, model_number, model_version,
        model_revision, cache, other):
        """See `IProcessorSet`."""
        store = get_hardware_store()
        platform = store.find(ProcessorPlatform, name=platform_name).one()
        if not platform:
            platform = ProcessorPlatform(platform_name)

        processor = store.find(
            Processor, platform=platform, make=make, model=model,
            model_number=model_number, model_version=model_version,
            model_revision=model_revision, cache=cache, other=other).one()
        if not processor:
            processor = Processor(
                platform, make, model, model_number, model_version,
                model_revision, cache, other)

        return processor


processor_set = ProcessorSet()
