# Copyright 2010-2011 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

__metaclass__ = type

__all__ = [
    "TestProcessorState",
    ]

from unittest import defaultTestLoader

from lpresults.hardware.testing.cases import TestCaseWithFactory
from lpresults.hardware.testing.layers import FunctionalDatabaseLayer


class TestProcessorState(TestCaseWithFactory):

    layer = FunctionalDatabaseLayer

    def test_speed(self):
        speed = self.factory.getUniqueInteger()
        state = self.factory.makeProcessorState(speed=speed)
        self.assertEquals(state.speed, speed)


class TestProcessorStateTargetMixin:

    layer = FunctionalDatabaseLayer

    def getProcessorStateTarget(self):
        raise NotImplementedError()

    def test_setProcessorState(self):
        target = self.getProcessorStateTarget()
        platform_name = self.factory.getUniqueString(u"platform")
        make = self.factory.getUniqueString(u"make")
        model = self.factory.getUniqueString(u"model")
        model_number = unicode(self.factory.getUniqueInteger())
        model_version = unicode(self.factory.getUniqueInteger())
        model_revision = unicode(self.factory.getUniqueInteger())
        cache = self.factory.getUniqueInteger()
        other = self.factory.getUniqueString(u"other")
        bogomips = self.factory.getUniqueInteger()
        speed = self.factory.getUniqueInteger()
        count = self.factory.getUniqueInteger()
        state = target.setProcessorState(platform_name, make, model,
        model_number, model_version, model_revision, cache, other,
        bogomips, speed, count)
        self.assertNotEquals(state, None)
        self.assertEquals(state.platform_name, platform_name)
        self.assertEquals(state.make, state.make)
        self.assertEquals(state.model, state.model)


def test_suite():
    return defaultTestLoader.loadTestsFromName(__name__)
