# Copyright 2010-2011 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

__metaclass__ = type

__all__ = [
    "ObjectFactory",
    ]

import os
import sys

from itertools import count


class ObjectFactory:

    # This allocates process-wide unique integers.  We count on Python doing
    # only cooperative threading to make this safe across threads.
    _unique_int_counter = count(100000)

    def getUniqueEmailAddress(self):
        return "%s@example.com" % self.getUniqueString("email")

    def getUniqueInteger(self):
        """Return an integer unique to this factory instance.

        For each thread, this will be a series of increasing numbers,
        but the starting point will be unique per thread.
        """
        return ObjectFactory._unique_int_counter.next()

    def getUniqueString(self, prefix=None):
        """Return a string unique to this factory instance.

        :param prefix: Used as a prefix for the unique string. If
            unspecified, defaults to "generic-string".
        """
        if prefix is None:
            frame = sys._getframe(2)
            source_filename = frame.f_code.co_filename
            # Dots and dashes cause trouble with some consumers of these
            # names.
            source = (
                os.path.basename(source_filename)
                .replace("_", "-")
                .replace(".", "-"))
            if source.startswith(
                    "<doctest "):
                # Like "-<doctest xx-build-summary-txt[10]>".
                source = (source
                    .replace("<doctest ", "")
                    .replace("[", "")
                    .replace("]>", ""))
            prefix = "unique-from-%s-line%d" % (
                source, frame.f_lineno)
        string = "%s-%s" % (prefix, self.getUniqueInteger())
        return string

    def getUniqueUnicode(self):
        return self.getUniqueString().decode("latin-1")
