# Copyright 2010-2011 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

__metaclass__ = type

__all__ = []

from cStringIO import StringIO

from unittest import (
    defaultTestLoader,
    TestCase,
    )

from lpresults.xunit.parsers.cputable import CputableParser


class CputableResult:

    def __init__(self):
        self.cpus = []

    def addCpu(self, cpu):
        self.cpus.append(cpu)

    def getByDebianName(self, name):
        for cpu in self.cpus:
            if cpu["debian_name"] == name:
                return cpu

        return None

    def getByGnuName(self, name):
        for cpu in self.cpus:
            if cpu["gnu_name"] == name:
                return cpu

        return None


class TestCputableParser(TestCase):

    def getParser(self, string):
        stream = StringIO(string)
        return CputableParser(stream)

    def getResult(self, string):
        parser = self.getParser(string)
        result = CputableResult()
        parser.run(result)
        return result

    def test_empty(self):
        result = self.getResult("")
        self.assertEquals(result.cpus, [])

    def test_i386(self):
        result = self.getResult("""
# <Debian name>	<GNU name>	<config.guess regex>	<Bits>	<Endianness>
i386		i686		(i[3456]86|pentium)	32	little
""")
        debian_cpu = result.getByDebianName("i386")
        self.assertNotEquals(debian_cpu, None)
        gnu_cpu = result.getByGnuName("i686")
        self.assertNotEquals(gnu_cpu, None)
        self.assertEquals(debian_cpu, gnu_cpu)


def test_suite():
    return defaultTestLoader.loadTestsFromName(__name__)
