/* Copyright 2010-2011 Canonical Ltd.  This software is licensed under the
 * GNU Affero General Public License version 3 (see the file LICENSE).
 *
 * The LPSearching module provides a class for paginating the results
 * from running an action.
 *
 * @module lpresults.lp
 * @submodule searching
 */
YUI.add('lpresults.lp.searching', function(Y) {

    var namespace = Y.namespace('lpresults.lp');

    var DEFAULT_CONTENT_SIZE = 75,
        DEFAULT_SEARCH_SIZE = 50;

    /**
     * The LPSearching class provides the ability to plugin functionality into
     * a DOM tree so that it can update itself when results are returned
     * from an action.
     *
     * @class LPSearching
     * @extends Widget
     * @constructor
     */
    var LPSearching = function() {
        LPSearching.superclass.constructor.apply(this, arguments);
    };

    Y.mix(LPSearching, {
        NAME: 'lpsearching',
        ATTRS: {
            /**
             * The element to initialize BatchingPlugin.
             *
             * @attribute controlBox
             * @type Node
             */
            controlBox: {
                value: null
            },

            /**
             * The element to initialize SearchingPlugin.
             *
             * @attribute controlBox
             * @type Node
             */
            searchBox: {
                value: null
            },

            /**
             * The hint to initialize the SearchingPlugin.
             *
             * @attribute searchHint
             * @type String
             */
            searchHint: {
                value: null
            }
        }
    });

    Y.extend(LPSearching, Y.lpresults.lp.LPContent, {
        /**
         * Get the searching content to render.
         *
         * @method getContent
         * @protected
         */
        getContent: function(action) {
            var content = new Y.lpresults.ui.Batching({
                action: action,
                sizeParameter: 'ws.size',
                startParameter: 'ws.start',
                contentBox: this.get('contentBox'),
                contentSize: DEFAULT_CONTENT_SIZE
                });
            content.plug(Y.lpresults.ui.BatchingPlugin, {
                controlBox: this.get('controlBox')
                });
            content.plug(Y.lpresults.ui.SearchingPlugin, {
                searchBox: this.get('searchBox'),
                searchHint: this.get('searchHint'),
                searchSize: DEFAULT_SEARCH_SIZE
                });

            return content;
        }
    });

    /*
     * Ensure that LPSearching is available within the lp namespace.
     */
    namespace.LPSearching = LPSearching;

}, '0.1', {'requires': [
    'lpresults.ui.searching', 'lpresults.ui.batching',
    'lpresults.lp.content']});
